.. django-auth-adfs documentation master file, created by
   sphinx-quickstart on Fri Jan 29 11:23:45 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-auth-adfs's documentation!
====================================================

Contents:

.. toctree::
   :maxdepth: 3

   readme
   contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

